@@ -8,20 +8,18 @@ OC.L10N.register(
     "Current" : "Actual",
     "Completed" : "Completáu",
     "Tasks" : "Xeres",
-    "New List" : "Nueva Llista",
-    "Cancel" : "Encaboxar",
-    "Save" : "Guardar",
-    "An empty name is not allowed." : "Nun s'almite un nome baleru",
-    "Share with users or groups" : "Compartir con usuarios y grupos",
-    "can edit" : "pue editar",
-    "Edit" : "Editar",
-    "Download" : "Baxar",
-    "Delete" : "Desaniciar",
-    "Unshare" : "Dexar de compartir",
     "Visibility of Smart Collections" : "Visibilidá de Coleiciones Intelixentes",
     "Hidden" : "Anubríu",
     "Visible" : "Visible",
     "Automatic" : "Automáticu",
+    "Share with users or groups" : "Compartir con usuarios y grupos",
+    "Edit" : "Editar",
+    "Download" : "Baxar",
+    "Delete" : "Desaniciar",
+    "Unshare" : "Dexar de compartir",
+    "Cancel" : "Encaboxar",
+    "Save" : "Guardar",
+    "An empty name is not allowed." : "Nun s'almite un nome baleru",
     "Change sort order" : "Camudar orde d'ordenación",
     "Priority" : "Prioridá",
     "Alphabetically" : "Alfabéticamente",
@@ -29,12 +27,13 @@ OC.L10N.register(
     "Task is completed" : "La xera ta completada",
     "_%n Completed Task_::_%n Completed Tasks_" : ["%n xera completada","%n xeres completaes"],
     "Tomorrow" : "Mañana",
-    "Set start date" : "Afitar la fecha d'entamu",
-    "Set due date" : "Afitar la data de caducidá",
+    "New List" : "Nueva Llista",
     "All day" : "Tol día",
-    "Task not found!" : "¡Xera non atopada!",
     "When shared show full event" : "Amosar l'eventu completu al compartir",
     "When shared show only busy" : "Amosar namás ocupáu al compartir",
-    "When shared hide this event" : "Anubrir l'eventu al compartir"
+    "When shared hide this event" : "Anubrir l'eventu al compartir",
+    "Task not found!" : "¡Xera non atopada!",
+    "Set start date" : "Afitar la fecha d'entamu",
+    "Set due date" : "Afitar la data de caducidá"
 },
 "nplurals=2; plural=(n != 1);");
