@@ -8,23 +8,22 @@ OC.L10N.register(
     "Current" : "Mövcud",
     "Completed" : "Bitmişdir",
     "Tasks" : "Tapşırıqlar",
-    "can edit" : "dəyişmək olar",
-    "New List" : "Yeni Siyahı",
-    "Cancel" : "Dayandır",
-    "Save" : "Saxla",
-    "An empty name is not allowed." : "Boş ada izin verilmir.",
-    "Edit" : "Dəyişiklik et",
-    "Download" : "Yüklə",
-    "Delete" : "Sil",
-    "Unshare" : "Paylaşımı durdur",
     "Visibility of Smart Collections" : "Ağıllı yiğımların görünməsi",
     "Hidden" : "Gizli",
     "Visible" : "Görünən",
     "Automatic" : "Avtomatik",
+    "Edit" : "Dəyişiklik et",
+    "Download" : "Yüklə",
+    "Delete" : "Sil",
+    "Unshare" : "Paylaşımı durdur",
+    "Cancel" : "Dayandır",
+    "Save" : "Saxla",
+    "An empty name is not allowed." : "Boş ada izin verilmir.",
     "_%n Completed Task_::_%n Completed Tasks_" : ["\"%s\" Bitmiş Tapşırıqlar","Completed Tasks"],
     "Tomorrow" : "Sabah",
+    "New List" : "Yeni Siyahı",
+    "Task not found!" : "Tapşırıq tapılmadı!",
     "Set start date" : "Başlanğıc tarixini işə sal",
-    "Set due date" : "Vaxtı təyin et",
-    "Task not found!" : "Tapşırıq tapılmadı!"
+    "Set due date" : "Vaxtı təyin et"
 },
 "nplurals=2; plural=(n != 1);");
