@@ -9,20 +9,18 @@ OC.L10N.register(
     "Completed" : "Completed",
     "Tasks" : "Tasks",
     "The Tasks app for Nextcloud" : "The Tasks app for Nextcloud",
-    "New List" : "New List",
-    "Cancel" : "Cancel",
-    "Save" : "Save",
-    "An empty name is not allowed." : "An empty name is not allowed.",
-    "Share with users or groups" : "Share with users or groups",
-    "can edit" : "can edit",
-    "Edit" : "Edit",
-    "Download" : "Download",
-    "Delete" : "Delete",
-    "Unshare" : "Unshare",
     "Visibility of Smart Collections" : "Visibility of Smart Collections",
     "Hidden" : "Hidden",
     "Visible" : "Visible",
     "Automatic" : "Automatic",
+    "Share with users or groups" : "Share with users or groups",
+    "Edit" : "Edit",
+    "Download" : "Download",
+    "Delete" : "Delete",
+    "Unshare" : "Unshare",
+    "Cancel" : "Cancel",
+    "Save" : "Save",
+    "An empty name is not allowed." : "An empty name is not allowed.",
     "Change sort order" : "Change sort order",
     "Start date" : "Start date",
     "Due date" : "Due date",
@@ -33,12 +31,13 @@ OC.L10N.register(
     "Task is completed" : "Task is completed",
     "_%n Completed Task_::_%n Completed Tasks_" : ["%n Completed Task","%n Completed Tasks"],
     "Tomorrow" : "Tomorrow",
-    "Set start date" : "Set start date",
-    "Set due date" : "Set due date",
+    "New List" : "New List",
     "All day" : "All day",
-    "Task not found!" : "Task not found!",
     "When shared show full event" : "When shared show full event",
     "When shared show only busy" : "When shared show only busy",
-    "When shared hide this event" : "When shared hide this event"
+    "When shared hide this event" : "When shared hide this event",
+    "Task not found!" : "Task not found!",
+    "Set start date" : "Set start date",
+    "Set due date" : "Set due date"
 },
 "nplurals=2; plural=(n != 1);");
