@@ -5,13 +5,12 @@ OC.L10N.register(
     "Week" : "Շաբաթ",
     "Current" : "Ընթացիկ",
     "Completed" : "Ավարտվեց",
-    "Cancel" : "Չեղարկել",
-    "Save" : "Պահել",
     "Share with users or groups" : "Կիսվել օգտատերերի կամ խմբերի հետ",
-    "can edit" : "կարող է խմբագրել",
     "Edit" : "Խմբագրել",
     "Download" : "Ներբեռնել",
     "Delete" : "Ջնջել",
-    "Unshare" : "Չկիսվել"
+    "Unshare" : "Չկիսվել",
+    "Cancel" : "Չեղարկել",
+    "Save" : "Պահել"
 },
 "nplurals=2; plural=(n != 1);");
