@@ -6,12 +6,11 @@ OC.L10N.register(
     "Week" : "សប្ដាហ៍",
     "All" : "ទាំងអស់",
     "Tasks" : "ភារកិច្ច",
-    "Cancel" : "បោះបង់",
-    "Save" : "រក្សាទុក",
-    "can edit" : "អាច​កែប្រែ",
     "Edit" : "កែប្រែ",
     "Download" : "ទាញយក",
     "Delete" : "លុប",
-    "Unshare" : "លែង​ចែក​រំលែក"
+    "Unshare" : "លែង​ចែក​រំលែក",
+    "Cancel" : "បោះបង់",
+    "Save" : "រក្សាទុក"
 },
 "nplurals=1; plural=0;");
